@@ -1,12 +1,34 @@
 ##
-##  Spreadsheet
+##  AS -- Accounting System
+##  Copyright (c) 2002 Cable & Wireless Deutschland <http://www.cw.com/de/>
+##  Copyright (c) 2002 Ralf S. Engelschall <rse@engelschall.com>
+##
+##  This file is part of AS, an accounting system which can be
+##  found at http://as.is.eu.cw.com/
+##
+##  This program is free software; you can redistribute it and/or
+##  modify it under the terms of the GNU General Public License
+##  as published by the Free Software Foundation; either version
+##  2.0 of the License, or (at your option) any later version.
+##
+##  This program is distributed in the hope that it will be useful,
+##  but WITHOUT ANY WARRANTY; without even the implied warranty of
+##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+##  General Public License for more details.
+##
+##  You should have received a copy of the GNU General Public License
+##  along with this program; if not, write to the Free Software
+##  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+##  USA, or contact The OSSP Project <ossp@ossp.org>.
+##
+##  as-cui-matrix.pm: Curses::UI based matrix/spreadsheet widget
 ##
 
 package as_cui_matrix;
 
 use strict;
-use Curses;         #OpenPKG perl-curses
-use Curses::UI;     #OpenPKG perl-curses
+use Curses;         # OpenPKG perl-curses
+use Curses::UI;     # OpenPKG perl-curses
 
 my $matrixdata = {};
 my $verbose  = 0;
@@ -717,18 +739,7 @@ sub keybinder {
         $vrscroll = +$matrixwidget->{"NumVisualRow"};
     }
     elsif ($key == KEY_F(1)) {
-        my $text = "";
-        my $io = new IO::File "<as-cui.help";
-        if (defined($io)) {
-            while (defined(my $ln = <$io>)) {
-                $text .= $ln;
-            }
-            $io->close();
-        }
-        else {
-            $text = "cannot open as-cui.help file";
-        }
-
+        my $text = `man as.cui 2>/dev/null` || "Cannot launch man or man page for as.cui not found";
         my $w = $this->parent->add("help", 'TextViewer',
             -x          => $matrixwidget->{"XOffset"},
             -y          => $matrixwidget->{"YOffset"},
@@ -1139,7 +1150,7 @@ sub ascui {
     my $wstat = $widget->{'stat'}->width;
     my $textl = "Accounting System (AS)";
     my $textr = "CTRL+X: menu  CTRL+Q: quit";
-    my $textf = " " x ($wstat -2 -length($textl) -1 -1 -length($textr) - 2);
+    my $textf = " " x ($wstat -2 -length($textl) -1 -1 -length($textr) - 2) . " ";
     my $text  = sprintf("  %s %s %s ", $textl, $textf, $textr);
     $widget->{'status'}->{-text} = $text;
     $widget->{'info'} = $widget->{'stat'}->add('info', 'Label',
@@ -1219,7 +1230,7 @@ sub ascui {
     } until ($breakout);
     &destroymatrixwidget();
 
-    $cui->dialog("Bye bye!");
+    # $cui->dialog("Bye bye!");
 }
 
 1;
